Class: Fortnox::Invoice
- Defined in:
- lib/fortnox/resources/invoice.rb
Constant Summary
Constants included from Types
Types::AccountNumber, Types::AccountingMethods, Types::ArticleTypes, Types::CURRENT_HOUSEWORK_TYPES, Types::Currencies, Types::CustomerTypes, Types::DefaultDeliveryTypeValues, Types::DeliveryStates, Types::DiscountTypes, Types::Email, Types::HouseworkTypes, Types::InvoiceTypes, Types::LEGACY_HOUSEWORK_TYPES, Types::PaymentWays, Types::ProjectStatusTypes, Types::THE_TRUTH, Types::TaxReductionTypes, Types::VATTypes
Instance Attribute Summary collapse
-
#accounting_method ⇒ Object
readonly
AccountingMethod Accounting Method.
-
#credit_invoice_reference ⇒ Object
readonly
CreditInvoiceReference Reference to the credit invoice, if one exists.
-
#invoice_period_reference ⇒ Object
readonly
InvoicePeriodReference Reference to the invoice period.
-
#invoice_reference ⇒ Object
readonly
InvoiceReference Reference to another invoice.
-
#invoice_type ⇒ Object
readonly
InvoiceType The type of invoice.
-
#payment_way ⇒ Object
readonly
PaymentWay Payment way of the invoice.
Attributes inherited from Document
#address1, #address2, #administration_fee, #city, #comments, #cost_center, #currency, #currency_rate, #currency_unit, #customer_name, #delivery_address1, #delivery_address2, #delivery_city, #delivery_name, #delivery_zip_code, #external_invoice_reference1, #external_invoice_reference2, #freight, #language, #our_reference, #phone1, #phone2, #price_list, #print_template, #project, #remarks, #tax_reduction_type, #terms_of_delivery, #terms_of_payment, #time_basis_reference, #total_to_pay, #way_of_delivery, #your_order_number, #your_reference, #zip_code
Method Summary
Methods inherited from Resource
find, find_all_by, find_one_by, only, parse, save, search, stub
Instance Attribute Details
#accounting_method ⇒ Object (readonly)
AccountingMethod Accounting Method.
14 15 16 |
# File 'lib/fortnox/resources/invoice.rb', line 14 def accounting_method @accounting_method end |
#credit_invoice_reference ⇒ Object (readonly)
CreditInvoiceReference Reference to the credit invoice, if one exists.
26 27 28 |
# File 'lib/fortnox/resources/invoice.rb', line 26 def credit_invoice_reference @credit_invoice_reference end |
#invoice_period_reference ⇒ Object (readonly)
InvoicePeriodReference Reference to the invoice period.
53 54 55 |
# File 'lib/fortnox/resources/invoice.rb', line 53 def invoice_period_reference @invoice_period_reference end |
#invoice_reference ⇒ Object (readonly)
InvoiceReference Reference to another invoice.
56 57 58 |
# File 'lib/fortnox/resources/invoice.rb', line 56 def invoice_reference @invoice_reference end |
#invoice_type ⇒ Object (readonly)
InvoiceType The type of invoice.
62 63 64 |
# File 'lib/fortnox/resources/invoice.rb', line 62 def invoice_type @invoice_type end |
#payment_way ⇒ Object (readonly)
PaymentWay Payment way of the invoice.
77 78 79 |
# File 'lib/fortnox/resources/invoice.rb', line 77 def payment_way @payment_way end |