Class: Fortnox::Article
- Defined in:
- lib/fortnox/resources/article.rb
Constant Summary
Constants included from Types
Types::AccountNumber, Types::AccountingMethods, Types::ArticleTypes, Types::CURRENT_HOUSEWORK_TYPES, Types::Currencies, Types::CustomerTypes, Types::DefaultDeliveryTypeValues, Types::DeliveryStates, Types::DiscountTypes, Types::Email, Types::HouseworkTypes, Types::InvoiceTypes, Types::LEGACY_HOUSEWORK_TYPES, Types::PaymentWays, Types::ProjectStatusTypes, Types::THE_TRUTH, Types::TaxReductionTypes, Types::VATTypes
Instance Attribute Summary collapse
-
#commodity_code ⇒ Object
readonly
CommodityCode Commodity code of the article.
-
#construction_account ⇒ Object
readonly
ConstructionAccount Account number for construction work (special VAT rules in Sweden).
-
#cost_calculation_method ⇒ Object
readonly
CostCalculationMethod Cost calculation method used for the article.
-
#default_stock_location ⇒ Object
readonly
DefaultStockLocation Default stock location for the article.
-
#default_stock_point ⇒ Object
readonly
DefaultStockPoint Default stock point for the article.
-
#depth ⇒ Object
readonly
Depth The depth of the article in millimeters.
-
#direct_cost ⇒ Object
readonly
DirectCost Direct cost of the article.
-
#export_account ⇒ Object
readonly
ExportAccount Account number for the sales account outside EU.
-
#freight_cost ⇒ Object
readonly
FreightCost Freight cost of the article.
-
#height ⇒ Object
readonly
Height The height of the article in millimeters.
-
#housework_type ⇒ Object
readonly
HouseworkType The type of housework.
-
#manufacturer ⇒ Object
readonly
Manufacturer The manufacturer of the article.
-
#manufacturer_article_number ⇒ Object
readonly
ManufacturerArticleNumber The manufacturer’s article number.
-
#note ⇒ Object
readonly
Note Text note.
-
#other_cost ⇒ Object
readonly
OtherCost Other cost of the article.
-
#purchase_account ⇒ Object
readonly
PurchaseAccount Account number for purchase.
-
#purchase_price ⇒ Object
readonly
PurchasePrice Purchase price of the article.
-
#quantity_in_stock ⇒ Object
readonly
QuantityInStock Quantity in stock of the article.
-
#sales_account ⇒ Object
readonly
SalesAccount Account number for the sales account in Sweden.
-
#stock_account ⇒ Object
readonly
StockAccount Account number for stock.
-
#stock_change_account ⇒ Object
readonly
StockChangeAccount Account number for stock changes.
-
#stock_place ⇒ Object
readonly
StockPlace Storage place for the article.
-
#stock_warning ⇒ Object
readonly
StockWarning When to start warning for low quantity in stock.
-
#supplier_number ⇒ Object
readonly
SupplierNumber Supplier number for the article.
-
#type ⇒ Object
readonly
Type The type of the article.
-
#unit ⇒ Object
readonly
Unit Unit code for the article.
-
#weight ⇒ Object
readonly
Weight Weight of the article in grams.
-
#width ⇒ Object
readonly
Width Width of the article in millimeters.
Method Summary
Methods inherited from Resource
find, find_all_by, find_one_by, inherited, only, parse, save, search, stub
Instance Attribute Details
#commodity_code ⇒ Object (readonly)
CommodityCode Commodity code of the article.
158 159 160 |
# File 'lib/fortnox/resources/article.rb', line 158 def commodity_code @commodity_code end |
#construction_account ⇒ Object (readonly)
ConstructionAccount Account number for construction work (special VAT rules in Sweden). The number must be of an existing account.
28 29 30 |
# File 'lib/fortnox/resources/article.rb', line 28 def construction_account @construction_account end |
#cost_calculation_method ⇒ Object (readonly)
CostCalculationMethod Cost calculation method used for the article.
134 135 136 |
# File 'lib/fortnox/resources/article.rb', line 134 def cost_calculation_method @cost_calculation_method end |
#default_stock_location ⇒ Object (readonly)
DefaultStockLocation Default stock location for the article.
155 156 157 |
# File 'lib/fortnox/resources/article.rb', line 155 def default_stock_location @default_stock_location end |
#default_stock_point ⇒ Object (readonly)
DefaultStockPoint Default stock point for the article.
152 153 154 |
# File 'lib/fortnox/resources/article.rb', line 152 def default_stock_point @default_stock_point end |
#depth ⇒ Object (readonly)
Depth The depth of the article in millimeters
31 32 33 |
# File 'lib/fortnox/resources/article.rb', line 31 def depth @depth end |
#direct_cost ⇒ Object (readonly)
DirectCost Direct cost of the article.
143 144 145 |
# File 'lib/fortnox/resources/article.rb', line 143 def direct_cost @direct_cost end |
#export_account ⇒ Object (readonly)
ExportAccount Account number for the sales account outside EU. The number must be of an existing account.
52 53 54 |
# File 'lib/fortnox/resources/article.rb', line 52 def export_account @export_account end |
#freight_cost ⇒ Object (readonly)
FreightCost Freight cost of the article.
146 147 148 |
# File 'lib/fortnox/resources/article.rb', line 146 def freight_cost @freight_cost end |
#height ⇒ Object (readonly)
Height The height of the article in millimeters
55 56 57 |
# File 'lib/fortnox/resources/article.rb', line 55 def height @height end |
#housework_type ⇒ Object (readonly)
HouseworkType The type of housework.
61 62 63 |
# File 'lib/fortnox/resources/article.rb', line 61 def housework_type @housework_type end |
#manufacturer ⇒ Object (readonly)
Manufacturer The manufacturer of the article
64 65 66 |
# File 'lib/fortnox/resources/article.rb', line 64 def manufacturer @manufacturer end |
#manufacturer_article_number ⇒ Object (readonly)
ManufacturerArticleNumber The manufacturer’s article number
67 68 69 |
# File 'lib/fortnox/resources/article.rb', line 67 def manufacturer_article_number @manufacturer_article_number end |
#note ⇒ Object (readonly)
Note Text note
70 71 72 |
# File 'lib/fortnox/resources/article.rb', line 70 def note @note end |
#other_cost ⇒ Object (readonly)
OtherCost Other cost of the article.
149 150 151 |
# File 'lib/fortnox/resources/article.rb', line 149 def other_cost @other_cost end |
#purchase_account ⇒ Object (readonly)
PurchaseAccount Account number for purchase. The number must be of an existing account.
74 75 76 |
# File 'lib/fortnox/resources/article.rb', line 74 def purchase_account @purchase_account end |
#purchase_price ⇒ Object (readonly)
PurchasePrice Purchase price of the article
77 78 79 |
# File 'lib/fortnox/resources/article.rb', line 77 def purchase_price @purchase_price end |
#quantity_in_stock ⇒ Object (readonly)
QuantityInStock Quantity in stock of the article
80 81 82 |
# File 'lib/fortnox/resources/article.rb', line 80 def quantity_in_stock @quantity_in_stock end |
#sales_account ⇒ Object (readonly)
SalesAccount Account number for the sales account in Sweden. The number must be of an existing account.
87 88 89 |
# File 'lib/fortnox/resources/article.rb', line 87 def sales_account @sales_account end |
#stock_account ⇒ Object (readonly)
StockAccount Account number for stock.
137 138 139 |
# File 'lib/fortnox/resources/article.rb', line 137 def stock_account @stock_account end |
#stock_change_account ⇒ Object (readonly)
StockChangeAccount Account number for stock changes.
140 141 142 |
# File 'lib/fortnox/resources/article.rb', line 140 def stock_change_account @stock_change_account end |
#stock_place ⇒ Object (readonly)
StockPlace Storage place for the article
96 97 98 |
# File 'lib/fortnox/resources/article.rb', line 96 def stock_place @stock_place end |
#stock_warning ⇒ Object (readonly)
StockWarning When to start warning for low quantity in stock
102 103 104 |
# File 'lib/fortnox/resources/article.rb', line 102 def stock_warning @stock_warning end |
#supplier_number ⇒ Object (readonly)
SupplierNumber Supplier number for the article. The number must be of an existing supplier.
109 110 111 |
# File 'lib/fortnox/resources/article.rb', line 109 def supplier_number @supplier_number end |
#type ⇒ Object (readonly)
Type The type of the article
112 113 114 |
# File 'lib/fortnox/resources/article.rb', line 112 def type @type end |
#unit ⇒ Object (readonly)
Unit Unit code for the article. The code must be of an existing unit.
116 117 118 |
# File 'lib/fortnox/resources/article.rb', line 116 def unit @unit end |
#weight ⇒ Object (readonly)
Weight Weight of the article in grams
125 126 127 |
# File 'lib/fortnox/resources/article.rb', line 125 def weight @weight end |
#width ⇒ Object (readonly)
Width Width of the article in millimeters.
128 129 130 |
# File 'lib/fortnox/resources/article.rb', line 128 def width @width end |