Class: Fortnox::Article

Inherits:
Resource
  • Object
show all
Defined in:
lib/fortnox/resources/article.rb

Constant Summary

Constants included from Types

Types::AccountNumber, Types::AccountingMethods, Types::ArticleTypes, Types::CURRENT_HOUSEWORK_TYPES, Types::Currencies, Types::CustomerTypes, Types::DefaultDeliveryTypeValues, Types::DeliveryStates, Types::DiscountTypes, Types::Email, Types::HouseworkTypes, Types::InvoiceTypes, Types::LEGACY_HOUSEWORK_TYPES, Types::PaymentWays, Types::ProjectStatusTypes, Types::THE_TRUTH, Types::TaxReductionTypes, Types::VATTypes

Instance Attribute Summary collapse

Method Summary

Methods inherited from Resource

find, find_all_by, find_one_by, only, parse, save, search, stub

Instance Attribute Details

#commodity_codeObject (readonly)

CommodityCode Commodity code of the article.



157
158
159
# File 'lib/fortnox/resources/article.rb', line 157

def commodity_code
  @commodity_code
end

#construction_accountObject (readonly)

ConstructionAccount Account number for construction work (special VAT rules in Sweden). The number must be of an existing account.



27
28
29
# File 'lib/fortnox/resources/article.rb', line 27

def 
  @construction_account
end

#cost_calculation_methodObject (readonly)

CostCalculationMethod Cost calculation method used for the article.



133
134
135
# File 'lib/fortnox/resources/article.rb', line 133

def cost_calculation_method
  @cost_calculation_method
end

#default_stock_locationObject (readonly)

DefaultStockLocation Default stock location for the article.



154
155
156
# File 'lib/fortnox/resources/article.rb', line 154

def default_stock_location
  @default_stock_location
end

#default_stock_pointObject (readonly)

DefaultStockPoint Default stock point for the article.



151
152
153
# File 'lib/fortnox/resources/article.rb', line 151

def default_stock_point
  @default_stock_point
end

#depthObject (readonly)

Depth The depth of the article in millimeters



30
31
32
# File 'lib/fortnox/resources/article.rb', line 30

def depth
  @depth
end

#direct_costObject (readonly)

DirectCost Direct cost of the article.



142
143
144
# File 'lib/fortnox/resources/article.rb', line 142

def direct_cost
  @direct_cost
end

#export_accountObject (readonly)

ExportAccount Account number for the sales account outside EU. The number must be of an existing account.



51
52
53
# File 'lib/fortnox/resources/article.rb', line 51

def 
  @export_account
end

#freight_costObject (readonly)

FreightCost Freight cost of the article.



145
146
147
# File 'lib/fortnox/resources/article.rb', line 145

def freight_cost
  @freight_cost
end

#heightObject (readonly)

Height The height of the article in millimeters



54
55
56
# File 'lib/fortnox/resources/article.rb', line 54

def height
  @height
end

#housework_typeObject (readonly)

HouseworkType The type of housework.



60
61
62
# File 'lib/fortnox/resources/article.rb', line 60

def housework_type
  @housework_type
end

#manufacturerObject (readonly)

Manufacturer The manufacturer of the article



63
64
65
# File 'lib/fortnox/resources/article.rb', line 63

def manufacturer
  @manufacturer
end

#manufacturer_article_numberObject (readonly)

ManufacturerArticleNumber The manufacturer’s article number



66
67
68
# File 'lib/fortnox/resources/article.rb', line 66

def manufacturer_article_number
  @manufacturer_article_number
end

#noteObject (readonly)

Note Text note



69
70
71
# File 'lib/fortnox/resources/article.rb', line 69

def note
  @note
end

#other_costObject (readonly)

OtherCost Other cost of the article.



148
149
150
# File 'lib/fortnox/resources/article.rb', line 148

def other_cost
  @other_cost
end

#purchase_accountObject (readonly)

PurchaseAccount Account number for purchase. The number must be of an existing account.



73
74
75
# File 'lib/fortnox/resources/article.rb', line 73

def 
  @purchase_account
end

#purchase_priceObject (readonly)

PurchasePrice Purchase price of the article



76
77
78
# File 'lib/fortnox/resources/article.rb', line 76

def purchase_price
  @purchase_price
end

#quantity_in_stockObject (readonly)

QuantityInStock Quantity in stock of the article



79
80
81
# File 'lib/fortnox/resources/article.rb', line 79

def quantity_in_stock
  @quantity_in_stock
end

#sales_accountObject (readonly)

SalesAccount Account number for the sales account in Sweden. The number must be of an existing account.



86
87
88
# File 'lib/fortnox/resources/article.rb', line 86

def 
  @sales_account
end

#stock_accountObject (readonly)

StockAccount Account number for stock.



136
137
138
# File 'lib/fortnox/resources/article.rb', line 136

def 
  @stock_account
end

#stock_change_accountObject (readonly)

StockChangeAccount Account number for stock changes.



139
140
141
# File 'lib/fortnox/resources/article.rb', line 139

def 
  @stock_change_account
end

#stock_placeObject (readonly)

StockPlace Storage place for the article



95
96
97
# File 'lib/fortnox/resources/article.rb', line 95

def stock_place
  @stock_place
end

#stock_warningObject (readonly)

StockWarning When to start warning for low quantity in stock



101
102
103
# File 'lib/fortnox/resources/article.rb', line 101

def stock_warning
  @stock_warning
end

#supplier_numberObject (readonly)

SupplierNumber Supplier number for the article. The number must be of an existing supplier.



108
109
110
# File 'lib/fortnox/resources/article.rb', line 108

def supplier_number
  @supplier_number
end

#typeObject (readonly)

Type The type of the article



111
112
113
# File 'lib/fortnox/resources/article.rb', line 111

def type
  @type
end

#unitObject (readonly)

Unit Unit code for the article. The code must be of an existing unit.



115
116
117
# File 'lib/fortnox/resources/article.rb', line 115

def unit
  @unit
end

#weightObject (readonly)

Weight Weight of the article in grams



124
125
126
# File 'lib/fortnox/resources/article.rb', line 124

def weight
  @weight
end

#widthObject (readonly)

Width Width of the article in millimeters.



127
128
129
# File 'lib/fortnox/resources/article.rb', line 127

def width
  @width
end